@@ -191,7 +191,7 @@ class LiveConsumer(_OTreeAsyncJsonWebsocketConsumer):
         ).exists()
 
     async def post_receive_json(self, content, participant_code, page_name, **kwargs):
-        if database_sync_to_async(self.browser_bot_exists)(participant_code):
+        if await database_sync_to_async(self.browser_bot_exists)(participant_code):
             return
         await database_sync_to_async(live_payload_function)(
             participant_code=participant_code, page_name=page_name, payload=content
@@ -795,6 +795,11 @@ class ExportData(_OTreeAsyncJsonWebsocketConsumer):
         return None
 
 
+class NoOp(WebsocketConsumer):
+    '''keep this in for a few months'''
+    pass
+
+
 def parse_querystring(query_string) -> dict:
     '''it seems parse_qs omits keys with empty values'''
     return {k: v[0] for k, v in urllib.parse.parse_qs(query_string.decode()).items()}
